summaryrefslogtreecommitdiffstats
path: root/btif
diff options
context:
space:
mode:
authorGanesh Ganapathi Batta <ganeshg@broadcom.com>2012-08-20 18:46:17 -0700
committerMatthew Xie <mattx@google.com>2012-08-24 13:52:26 -0700
commit30cd3fe33a8735c0b6096a1ff9470f6b0e62b5f1 (patch)
tree9a541eae458987c67fe9a050b0cfa31bf850bf2e /btif
parentbbca467023dd6334c21b52ed8e33cab0751c8d5e (diff)
downloadexternal_bluetooth_bluedroid-30cd3fe33a8735c0b6096a1ff9470f6b0e62b5f1.zip
external_bluetooth_bluedroid-30cd3fe33a8735c0b6096a1ff9470f6b0e62b5f1.tar.gz
external_bluetooth_bluedroid-30cd3fe33a8735c0b6096a1ff9470f6b0e62b5f1.tar.bz2
Ignore AVRCP Pause command from carkits right after the call
Certain carkits (e.g Audi MMI 2801)send AVRCP Pause command right after the call if there was an active music streaming when the call was answered. This command needs to be ignored as Phone/MediaPlayer will take care of music Play/pause after the call based on the state of the streaming before the call Change-Id: Iddb50089bff0f54bc3ad9665f95e64d3083c568a
Diffstat (limited to 'btif')
-rwxr-xr-x[-rw-r--r--]btif/src/btif_rc.c19
1 files changed, 10 insertions, 9 deletions
diff --git a/btif/src/btif_rc.c b/btif/src/btif_rc.c
index 248696a..1e8a220 100644..100755
--- a/btif/src/btif_rc.c
+++ b/btif/src/btif_rc.c
@@ -353,18 +353,19 @@ void handle_rc_passthrough_cmd ( tBTA_AV_REMOTE_CMD *p_remote_cmd)
pressed = 1;
}
- /* If this is Play command (press or release) before processing, check the following
- *a voice call has ended recently
- * the remote device is not of type headset
- * If the above conditions meet, drop the Play command
- *This fix is to interop with certain carkits which sends an automatic PLAY commands right after call ends
- */
- if((p_remote_cmd->rc_id == BTA_AV_RC_PLAY )&&
+ /* If this is Play/Pause command (press or release) before processing, check the following
+ * a voice call has ended recently
+ * the remote device is not of type headset
+ * If the above conditions meet, drop the Play/Pause command
+ * This fix is to interop with certain carkits which sends an automatic PLAY or PAUSE
+ * commands right after call ends
+ */
+ if((p_remote_cmd->rc_id == BTA_AV_RC_PLAY || p_remote_cmd->rc_id == BTA_AV_RC_PAUSE)&&
(btif_hf_call_terminated_recently() == TRUE) &&
(check_cod( (const bt_bdaddr_t*)&(btif_rc_cb.rc_addr), COD_AV_HEADSETS) != TRUE))
{
- BTIF_TRACE_DEBUG1("%s:Dropping the play command received right after call end",
- __FUNCTION__);
+ BTIF_TRACE_DEBUG2("%s:Dropping the play/Pause command received right after call end cmd:%d",
+ __FUNCTION__,p_remote_cmd->rc_id);
return;
}